"use strict";
exports.__esModule = true;
var request = require("request");
var typescriptDeferred = require("typescript-deferred");
var USMARTLiveDataClient = require("./usmartLiveDataClient");
var USMART = (function () {
    function USMART(auth) {
        this.authInfo = auth;
    }
    USMART.prototype.request = function (organisation, resource, revision, query) {
        var url = this.buildURL(organisation, resource, revision);
        var queryString = this.buildQuery(query);
        url += "?" + queryString;
        var headers;
        if (this.authInfo) {
            headers = {
                "api-key-id": this.authInfo.keyId,
                "api-key-secret": this.authInfo.keySecret
            };
        }
        var deferred = typescriptDeferred.create();
        request.get({
            headers: headers,
            url: url
        }, function (error, response, body) {
            if (error) {
                deferred.reject(body);
            }
            else {
                deferred.resolve(body);
            }
        });
        return deferred.promise;
    };
    USMART.prototype.subscribe = function (organisation, dataset, onMessage) {
        var _this = this;
        this.setupClient(function () {
            _this.client.subscribe(dataset, organisation).then(console.log);
        });
    };
    USMART.prototype.setupClient = function (callback) {
        this.client = new USMARTLiveDataClient.USMARTLiveDataClient(this.authInfo, true);
    };
    USMART.prototype.buildEqualQueries = function (equals) {
        var queries = [];
        equals.forEach(function (equalQuery) {
            queries.push("" + equalQuery.key + "=" + equalQuery.value);
        });
        return queries;
    };
    USMART.prototype.buildQuery = function (query) {
        var limit = query && query.limit ? query.limit : 10;
        var offset = query && query.offset ? query.offset : 0;
        var queries = [];
        queries.push("limit(" + limit + "," + offset + ")");
        if (query && query.equals) {
            queries = queries.concat(this.buildEqualQueries(query.equals));
        }
        return queries.join("&");
    };
    USMART.prototype.buildURL = function (organisation, resource, revision) {
        return "https://api.usmart.io/org/" + organisation + "/" + resource + "/" +
            (revision ? revision + "/" : "latest/") + "urql";
    };
    return USMART;
}());
exports.USMART = USMART;
